@@ -2,8 +2,8 @@
 #define PYTHONIC_INCLUDE_NUMPY_SQUARE_HPP
 
 #include "pythonic/include/types/numpy_op_helper.hpp"
-#include "pythonic/include/utils/numpy_traits.hpp"
 #include "pythonic/include/utils/functor.hpp"
+#include "pythonic/include/utils/numpy_traits.hpp"
 
 #include <complex>
 
@@ -19,7 +19,7 @@ namespace numpy
   namespace wrapper
   {
     template <class T>
-    auto square(T const &arg) -> decltype(arg *arg)
+    auto square(T const &arg) -> decltype(arg * arg)
     {
       return arg * arg;
     }
@@ -32,12 +32,12 @@ namespace numpy
       auto i2 = i * i;
       return {r2 - i2, t + t};
     }
-  }
+  } // namespace wrapper
 
 #define NUMPY_NARY_FUNC_NAME square
 #define NUMPY_NARY_FUNC_SYM wrapper::square
 #include "pythonic/include/types/numpy_nary_expr.hpp"
-}
+} // namespace numpy
 PYTHONIC_NS_END
 
 #endif
