@@ -2,14 +2,14 @@
 #define PYTHONIC_INCLUDE_TYPES_TUPLE_HPP
 
 #include "pythonic/include/types/assignable.hpp"
-#include "pythonic/include/types/traits.hpp"
 #include "pythonic/include/types/nditerator.hpp"
+#include "pythonic/include/types/traits.hpp"
 #include "pythonic/include/utils/int_.hpp"
-#include "pythonic/include/utils/seq.hpp"
 #include "pythonic/include/utils/nested_container.hpp"
+#include "pythonic/include/utils/seq.hpp"
 
-#include <tuple>
 #include <algorithm>
+#include <tuple>
 
 #if !defined(HAVE_SSIZE_T) || !HAVE_SSIZE_T
 #if defined(_MSC_VER)
@@ -26,7 +26,7 @@ namespace std
 
   template <class F0, class S0, class F1, class S1>
   bool operator==(pair<const F0, S0> const &self, tuple<F1, S1> const &other);
-}
+} // namespace std
 
 // Tuple concatenation with operator+
 template <class... Types0, class... Types1>
@@ -66,7 +66,7 @@ namespace types
   };
 
   template <class T, size_t N>
-  using array = array_base<T, N, tuple_version>;
+  using array_tuple = array_base<T, N, tuple_version>;
   template <class T, size_t N>
   using static_list = array_base<T, N, list_version>;
 
@@ -87,7 +87,8 @@ namespace types
   class str;
 
   struct slice;
-  struct contiguous_slice;
+  template <long stride>
+  struct cstride_slice;
 
   /* helper to extract the tail of a tuple, && pop the head */
   template <int Offset, class T, size_t... N>
@@ -112,12 +113,13 @@ namespace types
   template <class S, class... Stail>
   auto tuple_pop(std::tuple<S, Stail...> const &t)
       -> decltype(make_tuple_tail<count_trailing_long<Stail...>::value>(
-          t, utils::make_index_sequence<
-                 sizeof...(Stail)-count_trailing_long<Stail...>::value>{}))
+          t,
+          utils::make_index_sequence<sizeof...(Stail) -
+                                     count_trailing_long<Stail...>::value>{}))
   {
     return make_tuple_tail<count_trailing_long<Stail...>::value>(
-        t, utils::make_index_sequence<sizeof...(
-               Stail)-count_trailing_long<Stail...>::value>{});
+        t, utils::make_index_sequence<sizeof...(Stail) -
+                                      count_trailing_long<Stail...>::value>{});
   }
 
   template <class A, size_t... I, class... Types>
@@ -132,7 +134,7 @@ namespace types
 
   template <class... Tys>
   struct iterator<pshape<Tys...>> {
-    using type = array<long, sizeof...(Tys)>;
+    using type = array_tuple<long, sizeof...(Tys)>;
   };
 
   template <long N>
@@ -140,7 +142,7 @@ namespace types
   {
     return N;
   }
-  long check_type(long, long value)
+  inline long check_type(long, long value)
   {
     return value;
   }
@@ -228,16 +230,17 @@ namespace types
     pshape &operator=(pshape &&) = default;
 
     template <size_t... Is>
-    types::array<long, sizeof...(Tys)> array(utils::index_sequence<Is...>) const
+    types::array_tuple<long, sizeof...(Tys)>
+    array(utils::index_sequence<Is...>) const
     {
       return {{get<Is>()...}};
     }
 
-    types::array<long, sizeof...(Tys)> array() const
+    types::array_tuple<long, sizeof...(Tys)> array() const
     {
       return array(utils::make_index_sequence<sizeof...(Tys)>());
     }
-    operator types::array<long, sizeof...(Tys)>() const
+    operator types::array_tuple<long, sizeof...(Tys)>() const
     {
       return array();
     }
@@ -273,14 +276,14 @@ namespace types
 
   struct array_base_slicer {
     template <class T, size_t N>
-    dynamic_tuple<T> operator()(array<T, N> const &b, slice const &s);
+    dynamic_tuple<T> operator()(array_tuple<T, N> const &b, slice const &s);
+
+    template <class T, size_t N, long stride>
+    dynamic_tuple<T> operator()(array_tuple<T, N> const &b,
+                                cstride_slice<stride> const &s);
 
     template <class T, size_t N>
-    dynamic_tuple<T> operator()(array<T, N> const &b,
-                                contiguous_slice const &s);
-
-    template <class T, size_t N>
-    dynamic_tuple<T> operator()(array<T, N> const &b,
+    dynamic_tuple<T> operator()(array_tuple<T, N> const &b,
                                 fast_contiguous_slice const &s);
 
     template <class T, size_t N, class S>
@@ -304,7 +307,7 @@ namespace types
     {
       return extract_shape(e[0], utils::int_<L - 1>{});
     }
-  }
+  } // namespace details
 
   /* inspired by std::array implementation */
   template <typename T, size_t N, typename Version>
@@ -326,6 +329,7 @@ namespace types
     static const size_t value =
         utils::nested_container_depth<array_base>::value;
     static const bool is_vectorizable = true;
+    static const bool is_flat = true;
     static const bool is_strided = false;
 
     // flat_size implementation
@@ -401,8 +405,8 @@ namespace types
     const_reference operator[](long __n) const noexcept;
 
     template <class S>
-    auto operator[](S s) const
-        -> decltype(array_base_slicer{}(*this, (s.lower, s)))
+    auto operator[](S s) const -> decltype(array_base_slicer{}(*this,
+                                                               (s.lower, s)))
     {
       return array_base_slicer{}(*this, s);
     }
@@ -480,8 +484,8 @@ namespace types
 
     using shape_t = typename shape_builder<array_base, value>::type;
     template <size_t I>
-    auto shape() const
-        -> decltype(details::extract_shape(*this, utils::int_<I>{}))
+    auto shape() const -> decltype(details::extract_shape(*this,
+                                                          utils::int_<I>{}))
     {
       return details::extract_shape(*this, utils::int_<I>{});
     }
@@ -546,9 +550,10 @@ namespace types
           alike<T, typename std::remove_cv<typename std::remove_reference<
                        Types>::type>::type...>::value;
       using type = typename std::conditional<
-          value, typename alike<
-                     T, typename std::remove_cv<typename std::remove_reference<
-                            Types>::type>::type...>::type,
+          value,
+          typename alike<T,
+                         typename std::remove_cv<typename std::remove_reference<
+                             Types>::type>::type...>::type,
           void>::type;
     };
 
@@ -563,7 +568,7 @@ namespace types
                                 alike<T, typename alike<Types...>::type>::value;
       using type = typename alike<T, typename alike<Types...>::type>::type;
     };
-  }
+  } // namespace details
 
   template <class... Types>
   struct alike : details::alike<typename std::remove_cv<
@@ -574,7 +579,7 @@ namespace types
   // (static array for sames types || real tuple otherwise)
   template <bool Same, class... Types>
   struct _make_tuple {
-    auto operator()(Types &&... types)
+    auto operator()(Types &&...types)
         -> decltype(std::make_tuple(std::forward<Types>(types)...))
     {
       return std::make_tuple(std::forward<Types>(types)...);
@@ -583,15 +588,15 @@ namespace types
 
   template <class... Types>
   struct _make_tuple<true, Types...> {
-    types::array<typename alike<Types...>::type, sizeof...(Types)>
-    operator()(Types &&... types)
+    types::array_tuple<typename alike<Types...>::type, sizeof...(Types)>
+    operator()(Types &&...types)
     {
       return {{std::forward<Types>(types)...}};
     }
   };
 
   template <class... Types>
-  auto make_tuple(Types &&... types)
+  auto make_tuple(Types &&...types)
 #if !_MSC_VER || __clang__
       -> decltype(_make_tuple<alike<Types...>::value, Types...>()(
           std::forward<Types>(types)...))
@@ -605,14 +610,14 @@ namespace types
   using make_tuple_t = decltype(types::make_tuple(std::declval<Tys>()...));
 
   template <class T, class Tuple, size_t... S>
-  types::array<T, sizeof...(S)> _to_array(Tuple const &t,
-                                          utils::index_sequence<S...>)
+  types::array_tuple<T, sizeof...(S)> _to_array(Tuple const &t,
+                                                utils::index_sequence<S...>)
   {
     return {{static_cast<T>(std::get<S>(t))...}};
   }
 
   template <class T, class... Tys>
-  types::array<T, sizeof...(Tys)> to_array(std::tuple<Tys...> const &t)
+  types::array_tuple<T, sizeof...(Tys)> to_array(std::tuple<Tys...> const &t)
   {
     return _to_array<T>(t, utils::make_index_sequence<sizeof...(Tys)>());
   }
@@ -627,7 +632,7 @@ namespace types
   auto operator+(types::array_base<T, N, V> const &lt,
                  std::tuple<Types...> const &t)
       -> decltype(std::tuple_cat(lt.to_tuple(), t));
-}
+} // namespace types
 
 template <class... Types>
 struct assignable<std::tuple<Types...>> {
@@ -677,7 +682,7 @@ namespace std
   struct tuple_size<pythonic::types::array_base<T, N, V>> {
     static const size_t value = N;
   };
-}
+} // namespace std
 
 /* hashable tuples, as proposed in
  * http://stackoverflow.com/questions/7110301/generic-hash-for-tuples-in-unordered-map-unordered-set
@@ -695,7 +700,7 @@ namespace
   struct hash_impl<0, types...> {
     size_t operator()(size_t a, const std::tuple<types...> &t) const;
   };
-}
+} // namespace
 
 /* specialize std::hash */
 namespace std
@@ -709,7 +714,7 @@ namespace std
   struct hash<pythonic::types::array_base<T, N, V>> {
     size_t operator()(pythonic::types::array_base<T, N, V> const &l) const;
   };
-}
+} // namespace std
 
 /* type inference stuff  {*/
 #include "pythonic/include/types/combined.hpp"
@@ -730,8 +735,9 @@ struct __combined<pythonic::types::static_list<T, N>,
 };
 
 template <class T, size_t N>
-struct __combined<pythonic::types::array<T, N>, pythonic::types::array<T, N>> {
-  using type = pythonic::types::array<T, N>;
+struct __combined<pythonic::types::array_tuple<T, N>,
+                  pythonic::types::array_tuple<T, N>> {
+  using type = pythonic::types::array_tuple<T, N>;
 };
 
 template <class T0, class T1, size_t N, class V>
@@ -808,7 +814,7 @@ struct __combined<container<t>, std::tuple<t0...>> {
 PYTHONIC_NS_BEGIN
 namespace details
 {
-  template <class T, class P, bool Same>
+  template <class T, class P, bool Combine>
   struct pick_combined;
   template <class T, class P>
   struct pick_combined<T, P, true> {
@@ -816,9 +822,9 @@ namespace details
   };
   template <class T, class P>
   struct pick_combined<T, P, false> {
-    using type = P;
+    using type = T;
   };
-}
+} // namespace details
 PYTHONIC_NS_END
 
 template <long I, class t, class... t0>
@@ -827,10 +833,11 @@ struct __combined<std::tuple<t0...>,
   using holder = std::tuple<t0...>;
   template <size_t... Is>
   static std::tuple<typename pythonic::details::pick_combined<
-      t, typename std::tuple_element<Is, holder>::type, I == Is>::type...>
+      typename std::tuple_element<Is, holder>::type, t, I == Is>::type...>
       make_type(pythonic::utils::index_sequence<Is...>);
-  static auto make_type() -> decltype(
-      make_type(pythonic::utils::make_index_sequence<sizeof...(t0)>()));
+  static auto
+  make_type() -> decltype(make_type(
+                  pythonic::utils::make_index_sequence<sizeof...(t0)>()));
   using type = decltype(make_type());
 };
 
@@ -840,23 +847,23 @@ struct __combined<indexable_container<k, t>, std::tuple<t0...>>
 };
 
 template <class t, size_t n, class... types>
-struct __combined<pythonic::types::array<t, n>, std::tuple<types...>> {
+struct __combined<pythonic::types::array_tuple<t, n>, std::tuple<types...>> {
   using type = std::tuple<typename __combined<t, types>::type...>;
 };
 
 template <class t, size_t n, class... types>
-struct __combined<pythonic::types::array<t, n>,
+struct __combined<pythonic::types::array_tuple<t, n>,
                   pythonic::types::pshape<types...>> {
-  using type = pythonic::types::array<t, n>;
+  using type = pythonic::types::array_tuple<t, n>;
 };
 template <class t, size_t n, class... types>
 struct __combined<pythonic::types::pshape<types...>,
-                  pythonic::types::array<t, n>> {
-  using type = pythonic::types::array<t, n>;
+                  pythonic::types::array_tuple<t, n>> {
+  using type = pythonic::types::array_tuple<t, n>;
 };
 
 template <class t, size_t n, class... types>
-struct __combined<std::tuple<types...>, pythonic::types::array<t, n>> {
+struct __combined<std::tuple<types...>, pythonic::types::array_tuple<t, n>> {
   using type = std::tuple<typename __combined<types, t>::type...>;
 };
 template <class t00, class t01, class t10, class t11>
@@ -892,7 +899,7 @@ namespace types
   struct len_of<std::tuple<Types...>> {
     static constexpr long value = sizeof...(Types);
   };
-}
+} // namespace types
 PYTHONIC_NS_END
 
 namespace std
@@ -927,10 +934,10 @@ namespace std
 
   template <size_t I, class... Tys>
   struct tuple_element<I, pythonic::types::pshape<Tys...>> {
-    using type = typename std::tuple_element < I < sizeof...(Tys) ? I : 0,
-          std::tuple<Tys...>> ::type;
+    using type = typename std::tuple_element <
+                 I<sizeof...(Tys) ? I : 0, std::tuple<Tys...>>::type;
   };
-}
+} // namespace std
 PYTHONIC_NS_BEGIN
 namespace sutils
 {
@@ -942,7 +949,7 @@ namespace sutils
 
   template <typename T, size_t N, class V>
   struct make_shape<types::array_base<T, N, V>> {
-    using type = types::array<long, N>;
+    using type = types::array_tuple<long, N>;
   };
 
   template <class T>
@@ -1017,8 +1024,9 @@ namespace sutils
   struct shape_commonifier<std::integral_constant<long, N0>,
                            std::integral_constant<long, N1>, Ss...> {
     using type = typename std::conditional<
-        N0 == N1, typename shape_commonifier<std::integral_constant<long, N0>,
-                                             Ss...>::type,
+        N0 == N1,
+        typename shape_commonifier<std::integral_constant<long, N0>,
+                                   Ss...>::type,
         long>::type;
   };
 
@@ -1045,8 +1053,8 @@ namespace sutils
   template <class T>
   struct transpose;
   template <class T>
-  struct transpose<types::array<T, 2>> {
-    using type = types::array<T, 2>;
+  struct transpose<types::array_tuple<T, 2>> {
+    using type = types::array_tuple<T, 2>;
   };
 
   template <class T0, class T1>
@@ -1113,7 +1121,7 @@ namespace sutils
   };
   template <typename T, size_t N, class V>
   struct pop_tail<types::array_base<T, N, V>> {
-    using type = types::array<T, N - 1>;
+    using type = types::array_tuple<T, N - 1>;
   };
 
   template <class T>
@@ -1125,7 +1133,7 @@ namespace sutils
   };
   template <typename T, size_t N, class V>
   struct pop_head<types::array_base<T, N, V>> {
-    using type = types::array<T, N - 1>;
+    using type = types::array_tuple<T, N - 1>;
   };
 
   template <class T>
@@ -1150,7 +1158,8 @@ namespace sutils
   using head_t = typename head<T>::type;
 
   template <class... Tys>
-  types::array<long, sizeof...(Tys)> array(types::pshape<Tys...> const &pS)
+  types::array_tuple<long, sizeof...(Tys)>
+  array(types::pshape<Tys...> const &pS)
   {
     return pS.array();
   }
@@ -1161,8 +1170,8 @@ namespace sutils
     return pS;
   }
   template <class E, size_t... Is>
-  types::array<long, sizeof...(Is)> getshape(E const &e,
-                                             utils::index_sequence<Is...>)
+  types::array_tuple<long, sizeof...(Is)> getshape(E const &e,
+                                                   utils::index_sequence<Is...>)
   {
     return {(long)(e.template shape<Is>())...};
   }
@@ -1173,6 +1182,11 @@ namespace sutils
     return getshape(e, utils::make_index_sequence<E::value>());
   }
 
+  inline std::tuple<> getshape(...)
+  {
+    return {};
+  }
+
   template <class pS0, class pS1>
   struct concat;
 
@@ -1182,22 +1196,27 @@ namespace sutils
   };
 
   template <class... Tys>
-  struct concat<types::pshape<Tys...>, types::array<long, 0>> {
+  struct concat<types::pshape<Tys...>, types::array_tuple<long, 0>> {
     using type = types::pshape<Tys...>;
   };
   template <class... Tys, size_t N>
-  struct concat<types::pshape<Tys...>, types::array<long, N>>
-      : concat<types::pshape<Tys..., long>, types::array<long, N - 1>> {
+  struct concat<types::pshape<Tys...>, types::array_tuple<long, N>>
+      : concat<types::pshape<Tys..., long>, types::array_tuple<long, N - 1>> {
   };
 
   template <class... Ty1s>
-  struct concat<types::array<long, 0>, types::pshape<Ty1s...>> {
+  struct concat<types::array_tuple<long, 0>, types::pshape<Ty1s...>> {
     using type = types::pshape<Ty1s...>;
   };
 
   template <size_t N, class... Ty1s>
-  struct concat<types::array<long, N>, types::pshape<Ty1s...>>
-      : concat<types::array<long, N - 1>, types::pshape<long, Ty1s...>> {
+  struct concat<types::array_tuple<long, N>, types::pshape<Ty1s...>>
+      : concat<types::array_tuple<long, N - 1>, types::pshape<long, Ty1s...>> {
+  };
+
+  template <size_t N, size_t M>
+  struct concat<types::array_tuple<long, N>, types::array_tuple<long, M>> {
+    using type = types::array_tuple<long, N + M>;
   };
 
   template <class... Tys>
@@ -1223,8 +1242,9 @@ namespace sutils
   }
 
   template <class S>
-  long find(S &s, long v, long start = S::value,
-            bool comp(long, long) = [](long a, long b) { return (a == b); })
+  long find(
+      S &s, long v, long start = S::value,
+      bool comp(long, long) = [](long a, long b) { return (a == b); })
   {
     return find(s, v, std::integral_constant<size_t, S::value - 1>(), start,
                 comp);
@@ -1246,8 +1266,9 @@ namespace sutils
   }
 
   template <class S>
-  long sfind(S &s, long v, long start = std::tuple_size<S>::value,
-             bool comp(long, long) = [](long a, long b) { return (a == b); })
+  long sfind(
+      S &s, long v, long start = std::tuple_size<S>::value,
+      bool comp(long, long) = [](long a, long b) { return (a == b); })
   {
     return sfind(
         s, v, std::integral_constant<size_t, std::tuple_size<S>::value - 1>(),
@@ -1478,8 +1499,8 @@ namespace sutils
             decltype(copy_new_axis_helper<I - 1>{}.doit(
                 sutils::push_front_t<S0, typename std::tuple_element<
                                              J, typename S1::shape_t>::type>(),
-                shape, new_axis, std::integral_constant < size_t,
-                J == 0 ? J : J - 1 > ()))>::type
+                shape, new_axis,
+                std::integral_constant<size_t, J == 0 ? J : J - 1>()))>::type
     {
       return copy_new_axis_helper<I - 1>{}.doit(
           sutils::push_front_t<
@@ -1498,8 +1519,8 @@ namespace sutils
             decltype(copy_new_axis_helper<I - 1>{}.doit(
                 sutils::push_front_t<S0, typename std::tuple_element<
                                              J, typename S1::shape_t>::type>(),
-                shape, new_axis, std::integral_constant < size_t,
-                J == 0 ? J : J - 1 > ()))>::type
+                shape, new_axis,
+                std::integral_constant<size_t, J == 0 ? J : J - 1>()))>::type
     {
       return copy_new_axis_helper<I - 1>{}.doit(
           sutils::push_front_t<
@@ -1521,7 +1542,7 @@ namespace sutils
         types::pshape<>(), shape, new_axis,
         std::integral_constant<size_t, S1::value - 1>());
   }
-}
+} // namespace sutils
 
 namespace types
 {
@@ -1538,7 +1559,7 @@ namespace types
       sutils::assign(std::get<std::tuple_size<S>::value - L>(res), e.size());
       init_shape(res, e[0], utils::int_<L - 1>{});
     }
-  }
+  } // namespace details
   template <class T, class... Tys>
   bool operator==(T const &self, pshape<Tys...> const &other)
   {
@@ -1569,14 +1590,14 @@ namespace types
   {
     return !sutils::equals(self, other);
   }
-}
+} // namespace types
 
 PYTHONIC_NS_END
 
 #ifdef ENABLE_PYTHON_MODULE
 
-#include "pythonic/include/utils/seq.hpp"
 #include "pythonic/include/utils/fwd.hpp"
+#include "pythonic/include/utils/seq.hpp"
 #include "pythonic/python/core.hpp"
 
 PYTHONIC_NS_BEGIN
@@ -1602,12 +1623,12 @@ struct to_python<std::tuple<Types...>> {
 };
 
 template <typename T, size_t N>
-struct to_python<types::array<T, N>> {
+struct to_python<types::array_tuple<T, N>> {
   template <size_t... S>
-  static PyObject *do_convert(types::array<T, N> const &t,
+  static PyObject *do_convert(types::array_tuple<T, N> const &t,
                               utils::index_sequence<S...>);
 
-  static PyObject *convert(types::array<T, N> const &t);
+  static PyObject *convert(types::array_tuple<T, N> const &t);
 };
 
 template <typename T, size_t N>
@@ -1635,14 +1656,14 @@ struct from_python<std::tuple<Types...>> {
 };
 
 template <typename T, size_t N>
-struct from_python<types::array<T, N>> {
+struct from_python<types::array_tuple<T, N>> {
 
   static bool is_convertible(PyObject *obj);
 
   template <size_t... S>
-  static types::array<T, N> do_convert(PyObject *obj,
-                                       typename utils::index_sequence<S...>);
-  static types::array<T, N> convert(PyObject *obj);
+  static types::array_tuple<T, N>
+  do_convert(PyObject *obj, typename utils::index_sequence<S...>);
+  static types::array_tuple<T, N> convert(PyObject *obj);
 };
 PYTHONIC_NS_END
 #endif
