@@ -10,13 +10,12 @@ PYTHONIC_NS_BEGIN
 
 namespace random
 {
-
-  double random()
+  inline double random()
   {
     static std::uniform_real_distribution<> uniform_distrib(0.0, 1.0);
     return uniform_distrib(__random_generator);
   }
-}
+} // namespace random
 PYTHONIC_NS_END
 
 #endif
