@@ -2,8 +2,6 @@ from pythran.tests import TestEnv
 from pythran.typing import NDArray, Tuple, List
 
 import numpy
-from distutils.version import LooseVersion
-
 import unittest
 
 try:
@@ -54,6 +52,11 @@ class TestNdarray(TestEnv):
                       numpy.uintp(5),
                       ndarray_uintp=[numpy.uintp])
 
+    def test_ndarray_bool(self):
+        self.run_test('def ndarray_bool(b): import numpy as np; return np.bool_(b), np.array([b], dtype=np.bool_)',
+                      numpy.bool_(5),
+                      ndarray_bool=[bool])
+
     def test_ndarray_real_attr_read(self):
         self.run_test('def ndarray_real_attr_read(a): return a.real + 1',
                       numpy.arange(100, dtype=numpy.complex128).reshape((10, 10)),
@@ -104,6 +107,16 @@ class TestNdarray(TestEnv):
                       1j * numpy.arange(10, dtype=numpy.complex128),
                       ndarray_imag_vexpr_read=[NDArray[complex, :]])
 
+    def test_ndarray_real_iexpr_read(self):
+        self.run_test('def ndarray_real_iexpr_read(a): return a[1].real',
+                      numpy.arange(10, dtype=numpy.complex128),
+                      ndarray_real_iexpr_read=[NDArray[complex, :]])
+
+    def test_ndarray_imag_iexpr_read(self):
+        self.run_test('def ndarray_imag_iexpr_read(a): return a[1].imag',
+                      1j * numpy.arange(10, dtype=numpy.complex128),
+                      ndarray_imag_iexpr_read=[NDArray[complex, :]])
+
     def test_numpy_augassign0(self):
         self.run_test('def numpy_augassign0(a): a+=1; return a',
                       numpy.arange(100).reshape((10, 10)),
@@ -735,6 +748,21 @@ def newaxis8(n):
                       numpy.arange(4).reshape(2,2), numpy.array([[0, 1], [2, 3]]),
                       gexpr_baseid1=[NDArray[int,:,:], NDArray[int, :, :]])
 
+    def test_gexpr_baseid2(self):
+        code = """
+import numpy as np
+def gexpr_baseid2(N):
+    B = np.zeros((N,N), dtype=int)
+    A = [[0] for ii in range(N)]
+    for ii in range(len(A)):
+        a = len(A[ii])
+        B[ii, 0:a] = A[ii][0:a]
+    return B
+        """
+        self.run_test(code,
+                      100,
+                      gexpr_baseid2=[int])
+
     def test_gexpr_copy0(self):
         self.run_test("def gexpr_copy0(a,b): a[:,0] = b[:,0]; return a",
                       numpy.arange(16).reshape(8,2), numpy.arange(16).reshape(8,2),
@@ -750,6 +778,21 @@ def newaxis8(n):
                       numpy.arange(5), [1] * 5,
                       gexpr_copy2=[NDArray[int, :], List[int]])
 
+    def test_gexpr_copy3(self):
+        self.run_test("def gexpr_copy3(a,b): assert a is not b; a[1:] = b[:-1]; return a",
+                      numpy.arange(5), numpy.array([1] * 5),
+                      gexpr_copy3=[NDArray[int, :], NDArray[int, :]])
+
+    def test_gexpr_copy4(self):
+        self.run_test("def gexpr_copy4(a): b = a; a[1:] = b[:-1]; return a",
+                      numpy.arange(5),
+                      gexpr_copy4=[NDArray[int, :]])
+
+    def test_gexpr_copy5(self):
+        self.run_test("def gexpr_copy5(a): b = a if len(a) else a.copy(); a[1:] = b[:-1]; return a",
+                      numpy.arange(5),
+                      gexpr_copy5=[NDArray[int, :]])
+
     def test_ndarray_iter0(self):
         self.run_test("def ndarray_iter0(a): return list(map(str, a))",
                       numpy.arange(16),
