@@ -347,21 +347,23 @@ def full_unroll0():
     for i,j in zip([1,2,3],[4,5,6]): k.append((i,j))
     return k"""
 
-        ref = '''def full_unroll0():
-    k = []
-    __tuple0 = (1, 4)
-    j = __tuple0[1]
-    i = __tuple0[0]
-    builtins.list.append(k, (i, j))
-    __tuple0 = (2, 5)
-    j = __tuple0[1]
-    i = __tuple0[0]
-    builtins.list.append(k, (i, j))
-    __tuple0 = (3, 6)
-    j = __tuple0[1]
-    i = __tuple0[0]
-    builtins.list.append(k, (i, j))
-    return k'''
+        ref = '''
+        import __dispatch__ as __pythran_import___dispatch__
+        def full_unroll0():
+            k = []
+            __tuple0 = (1, 4)
+            j = __tuple0[1]
+            i = __tuple0[0]
+            __pythran_import___dispatch__.append(k, (i, j))
+            __tuple0 = (2, 5)
+            j = __tuple0[1]
+            i = __tuple0[0]
+            __pythran_import___dispatch__.append(k, (i, j))
+            __tuple0 = (3, 6)
+            j = __tuple0[1]
+            i = __tuple0[0]
+            __pythran_import___dispatch__.append(k, (i, j))
+            return k'''
         self.check_ast(init, ref, ["pythran.optimizations.ConstantFolding", "pythran.optimizations.LoopFullUnrolling"])
 
 
